@@ -3,9 +3,9 @@
  *
  * 
  * Copyright (C) 1997   Aleph One
- * Copyright (C) 1997-8 Andrew G. Morgan <morgan@linux.kernel.org>
+ * Copyright (C) 1997-8 Andrew G. Morgan <morgan@kernel.org>
  *
- * POSIX.1e Standard: 25.2 Capabilities                 <sys/capability.h>
+ * defunct POSIX.1e Standard: 25.2 Capabilities           <sys/capability.h>
  */
 
 #ifndef _SYS_CAPABILITY_H
@@ -21,6 +21,17 @@ extern "C" {
  */
 
 #include <sys/types.h>
+#include <stdint.h>
+
+/*
+ * Make sure we can be included from userland by preventing
+ * capability.h from including other kernel headers
+ */
+#define _LINUX_TYPES_H
+#define _LINUX_FS_H
+
+typedef unsigned int __u32;
+
 #include <linux/capability.h>
 
 /*
